==> apache-openmeetings-7.2.0.tar.gz: META-INF/resources/webjars/eonasdan__tempus-dominus/6.7.11/README.md <==
[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/R6R53OEFF)

# Tempus Dominus Date/Time Picker v6.7.11

Tempus Dominus is a powerful and robust date time picker for javascript. Version 6 is another major rewrite over the previous version. V6 is written with modern browsers in mind and is written in typescript. Bootstrap, momentjs and jQuery are no longer required dependencies. Popper2 is all that is required for the picker to position correctly. If you still require jQuery (seriously, you should move off that asap) there's a jQuery provider that wraps the native js functions.

# Ready State

V6 has shipped! You can see the [rough roadmap here](https://github.com/users/Eonasdan/projects/1).

# Community

Need help or want to discuss some? Join [the discord](https://discord.gg/BHS9jw9YPf).

Please also take a look at the [discussions](https://github.com/Eonasdan/tempus-dominus/discussions). There are several RFCs (Request For Comment) open, and you can help shape the future of the picker by participating in these discussions.

# Developers

## Building

Run `npm i` to install needed packages.

The docs folder contains the generated documentation site, don't modify this directly as it will be overwritten on build. The dist folder contains the built js/css files.

## Running

You can run `npm run serve` which will start a web server. Navigate to `http://localhost:3001/` to view the docs.

## Watching for changes

Do not run `npm run serve` at the same time.

Run `npm start`. This runs web server, the build and watchers for the docs, styles, and typescript.

## Where do you use this?

I'd love to know if your public site is using this plugin and list your logo on the documentation site. Leave [create a discussion](https://github.com/Eonasdan/tempus-dominus/discussions/categories/show-your-love) and let me know.

## Priority support is available at an hourly rate.

If you have an urgent request, bug or need installation help, please contact in the discord server.

==> apache-openmeetings-8.1.0.tar.gz: META-INF/resources/webjars/eonasdan__tempus-dominus/6.10.4/README.md <==
[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/R6R53OEFF)

# Paid support only

Please note that I'm moving on to other projects. New issues will need to be sponsored. This can be done via BountySource or my other donation links. Please reach out to me first so we can discuss the terms. Thank you for your years of support.

# Tempus Dominus Date/Time Picker v6.9.4

Tempus Dominus is a powerful and robust date time picker for javascript. Version 6 is another major rewrite over the previous version. V6 is written with modern browsers in mind and is written in typescript. Bootstrap, momentjs and jQuery are no longer required dependencies. Popper2 is all that is required for the picker to position correctly. If you still require jQuery (seriously, you should move off that asap) there's a jQuery provider that wraps the native js functions.

# Developers

## Building

Run `npm i` to install needed packages.

The docs folder contains the generated documentation site, don't modify this directly as it will be overwritten on build. The dist folder contains the built js/css files.

## Running

You can run `npm run serve` which will start a web server. Navigate to `http://localhost:3001/` to view the docs.

## Watching for changes

Do not run `npm run serve` at the same time.

Run `npm start`. This runs web server, the build and watchers for the docs, styles, and typescript.

## Where do you use this?

I'd love to know if your public site is using this plugin and list your logo on the documentation site. Leave [create a discussion](https://github.com/Eonasdan/tempus-dominus/discussions/categories/show-your-love) and let me know.

## Priority support is available at an hourly rate.

If you have an urgent request, bug or need installation help, please contact in the discord server.
